@@ -1,5 +1,5 @@
 from .collection import Collection, Enum
 from .fields import (StringField, IntegerField, DateField, DateTimeField, BooleanField, FloatField, EmailField,
                      EnumField, ReferenceField, ManyToManyField, SlugField)
-from .db import Database
+from .project import Project
 from .client import FaunaClient
